@@ -2,93 +2,91 @@ require 'spec_helper'
 
 describe 'glance::api' do
   let :pre_condition do
-    "class { '::glance::api::authtoken':
+    "class { 'glance::api::authtoken':
       password => 'ChangeMe',
     }"
   end
 
   let :default_params do
     {
-      :bind_host                      => '<SERVICE DEFAULT>',
-      :bind_port                      => '9292',
-      :registry_host                  => '0.0.0.0',
-      :registry_port                  => '<SERVICE DEFAULT>',
-      :registry_client_protocol       => '<SERVICE DEFAULT>',
-      :auth_strategy                  => 'keystone',
-      :enabled                        => true,
-      :manage_service                 => true,
-      :backlog                        => '<SERVICE DEFAULT>',
-      :workers                        => '7',
-      :show_image_direct_url          => '<SERVICE DEFAULT>',
-      :show_multiple_locations        => '<SERVICE DEFAULT>',
+      :bind_host                => '<SERVICE DEFAULT>',
+      :bind_port                => '9292',
+      :registry_host            => '0.0.0.0',
+      :registry_port            => '<SERVICE DEFAULT>',
+      :registry_client_protocol => '<SERVICE DEFAULT>',
+      :auth_strategy            => 'keystone',
+      :enabled                  => true,
+      :manage_service           => true,
+      :backlog                  => '<SERVICE DEFAULT>',
+      :workers                  => '7',
+      :show_image_direct_url    => '<SERVICE DEFAULT>',
+      :show_multiple_locations  => '<SERVICE DEFAULT>',
       :filesystem_store_metadata_file => '<SERVICE DEFAULT>',
-      :filesystem_store_file_perm     => '<SERVICE DEFAULT>',
-      :location_strategy              => '<SERVICE DEFAULT>',
-      :purge_config                   => false,
-      :delayed_delete                 => '<SERVICE DEFAULT>',
-      :scrub_time                     => '<SERVICE DEFAULT>',
-      :image_cache_dir                => '/var/lib/glance/image-cache',
-      :image_import_plugins           => '<SERVICE DEFAULT>',
+      :filesystem_store_file_perm => '<SERVICE DEFAULT>',
+      :location_strategy        => '<SERVICE DEFAULT>',
+      :purge_config             => false,
+      :delayed_delete           => '<SERVICE DEFAULT>',
+      :scrub_time               => '<SERVICE DEFAULT>',
+      :image_cache_dir          => '/var/lib/glance/image-cache',
+      :image_import_plugins     => '<SERVICE DEFAULT>',
       :image_conversion_output_format => '<SERVICE DEFAULT>',
-      :inject_metadata_properties     => '<SERVICE DEFAULT>',
-      :ignore_user_roles              => '<SERVICE DEFAULT>',
-      :enabled_import_methods         => '<SERVICE DEFAULT>',
-      :node_staging_uri               => '<SERVICE DEFAULT>',
-      :image_member_quota             => '<SERVICE DEFAULT>',
-      :image_cache_stall_time         => '<SERVICE DEFAULT>',
-      :image_cache_max_size           => '<SERVICE DEFAULT>',
-      :cache_prefetcher_interval      => '<SERVICE DEFAULT>',
-      :os_region_name                 => 'RegionOne',
-      :pipeline                       => 'keystone',
-      :task_time_to_live              => '<SERVICE DEFAULT>',
-      :task_executor                  => '<SERVICE DEFAULT>',
-      :task_work_dir                  => '<SERVICE DEFAULT>',
-      :taskflow_engine_mode           => '<SERVICE DEFAULT>',
-      :taskflow_max_workers           => '<SERVICE DEFAULT>',
-      :conversion_format              => '<SERVICE DEFAULT>',
-      :enable_v1_api                  => false,
-      :enable_v2_api                  => '<SERVICE DEFAULT>',
-      :sync_db                        => true,
-      :limit_param_default            => '<SERVICE DEFAULT>',
-      :api_limit_max                  => '<SERVICE DEFAULT>',
+      :inject_metadata_properties => '<SERVICE DEFAULT>',
+      :ignore_user_roles        => '<SERVICE DEFAULT>',
+      :enabled_import_methods   => '<SERVICE DEFAULT>',
+      :node_staging_uri         => '<SERVICE DEFAULT>',
+      :image_member_quota       => '<SERVICE DEFAULT>',
+      :image_cache_stall_time   => '<SERVICE DEFAULT>',
+      :image_cache_max_size     => '<SERVICE DEFAULT>',
+      :os_region_name           => 'RegionOne',
+      :pipeline                 => 'keystone',
+      :task_time_to_live        => '<SERVICE DEFAULT>',
+      :task_executor            => '<SERVICE DEFAULT>',
+      :task_work_dir            => '<SERVICE DEFAULT>',
+      :taskflow_engine_mode     => '<SERVICE DEFAULT>',
+      :taskflow_max_workers     => '<SERVICE DEFAULT>',
+      :conversion_format        => '<SERVICE DEFAULT>',
+      :enable_v1_api            => false,
+      :enable_v2_api            => '<SERVICE DEFAULT>',
+      :sync_db                  => true,
+      :limit_param_default      => '<SERVICE DEFAULT>',
+      :api_limit_max            => '<SERVICE DEFAULT>',
     }
   end
 
   shared_examples_for 'glance::api' do
 
     [{
-        :bind_host                      => '127.0.0.1',
-        :bind_port                      => '9222',
-        :registry_host                  => '127.0.0.1',
-        :registry_port                  => '9111',
-        :registry_client_protocol       => 'https',
-        :auth_strategy                  => 'not_keystone',
-        :enabled                        => false,
-        :backlog                        => '4095',
-        :workers                        => '5',
-        :show_image_direct_url          => true,
-        :show_multiple_locations        => true,
+        :bind_host                => '127.0.0.1',
+        :bind_port                => '9222',
+        :registry_host            => '127.0.0.1',
+        :registry_port            => '9111',
+        :registry_client_protocol => 'https',
+        :auth_strategy            => 'not_keystone',
+        :enabled                  => false,
+        :backlog                  => '4095',
+        :workers                  => '5',
+        :show_image_direct_url    => true,
+        :show_multiple_locations  => true,
         :filesystem_store_metadata_file => '/etc/glance/glance-metadata-file.conf',
-        :filesystem_store_file_perm     => '0644',
-        :location_strategy              => 'store_type',
-        :delayed_delete                 => 'true',
-        :scrub_time                     => '10',
-        :image_cache_dir                => '/tmp/glance',
-        :image_import_plugins           => 'image_conversion',
+        :filesystem_store_file_perm => '0644',
+        :location_strategy        => 'store_type',
+        :delayed_delete           => 'true',
+        :scrub_time               => '10',
+        :image_cache_dir          => '/tmp/glance',
+        :image_import_plugins     => 'image_conversion',
         :image_conversion_output_format => 'raw',
-        :inject_metadata_properties     => 'key:val',
-        :ignore_user_roles              => 'admin',
-        :enabled_import_methods         => 'glance-direct,web-download',
-        :node_staging_uri               => '/tmp/staging',
-        :image_member_quota             => '128',
-        :image_cache_stall_time         => '10',
-        :image_cache_max_size           => '10737418240',
-        :cache_prefetcher_interval      => '300',
-        :os_region_name                 => 'RegionOne2',
-        :pipeline                       => 'keystone2',
-        :sync_db                        => false,
-        :limit_param_default            => '10',
-        :api_limit_max                  => '10',
+        :inject_metadata_properties => 'key:val',
+        :ignore_user_roles        => 'admin',
+        :enabled_import_methods   => 'glance-direct,web-download',
+        :node_staging_uri         => '/tmp/staging',
+        :image_member_quota       => '128',
+        :image_cache_stall_time   => '10',
+        :image_cache_max_size     => '10737418240',
+        :os_region_name           => 'RegionOne2',
+        :pipeline                 => 'keystone2',
+        :sync_db                  => false,
+        :limit_param_default      => '10',
+        :api_limit_max            => '10',
       }
     ].each do |param_set|
 
@@ -139,7 +137,6 @@ describe 'glance::api' do
             'image_cache_dir',
             'image_cache_stall_time',
             'image_cache_max_size',
-            'cache_prefetcher_interval',
             'node_staging_uri',
             'image_member_quota',
             'enable_v1_api',
